@@ -229,7 +229,11 @@ _CONTAINER_TYPES = {
                               well_coating=None,
                               sterile=False,
                               is_tube=False,
-                              capabilities=[],
+                              capabilities=["pipette", "spin", "absorbance",
+                                            "fluorescence", "luminescence",
+                                            "incubate", "gel_separate",
+                                            "gel_purify", "cover", "stamp",
+                                            "dispense"],
                               shortname="384-flat",
                               col_count=24,
                               dead_volume_ul=Unit(5, "microliter"),
@@ -241,7 +245,9 @@ _CONTAINER_TYPES = {
                              well_coating=None,
                              sterile=None,
                              is_tube=False,
-                             capabilities=[],
+                             capabilities=["pipette", "spin", "thermocycle",
+                                           "incubate", "gel_separate", "gel_purify",
+                                           "seal", "stamp", "dispense"],
                              shortname="384-pcr",
                              col_count=24,
                              dead_volume_ul=Unit(2, "microliter"),
@@ -253,7 +259,9 @@ _CONTAINER_TYPES = {
                               well_coating=None,
                               sterile=None,
                               is_tube=False,
-                              capabilities=[],
+                              capabilities=["pipette", "seal", "spin",
+                                            "incubate", "stamp", "dispense",
+                                            "cover"],
                               shortname="384-echo",
                               col_count=24,
                               dead_volume_ul=Unit(15, "microliter"),
@@ -265,7 +273,11 @@ _CONTAINER_TYPES = {
                              well_coating=None,
                              sterile=False,
                              is_tube=False,
-                             capabilities=[],
+                             capabilities=["pipette", "spin", "absorbance",
+                                           "fluorescence", "luminescence",
+                                           "incubate", "gel_separate",
+                                           "gel_purify", "cover", "stamp",
+                                           "dispense"],
                              shortname="96-flat",
                              col_count=12,
                              dead_volume_ul=Unit(25, "microliter"),
@@ -278,7 +290,11 @@ _CONTAINER_TYPES = {
                                 well_coating=None,
                                 sterile=False,
                                 is_tube=False,
-                                capabilities=[],
+                                capabilities=["pipette", "spin", "absorbance",
+                                              "fluorescence", "luminescence",
+                                              "incubate", "gel_separate",
+                                              "gel_purify", "cover", "stamp",
+                                              "dispense"],
                                 shortname="96-flat-uv",
                                 col_count=12,
                                 dead_volume_ul=Unit(25, "microliter"),
@@ -290,7 +306,10 @@ _CONTAINER_TYPES = {
                             well_coating=None,
                             sterile=None,
                             is_tube=False,
-                            capabilities=[],
+                            capabilities=["pipette", "sangerseq", "spin",
+                                          "thermocycle", "incubate",
+                                          "gel_separate", "gel_purify",
+                                          "seal", "stamp", "dispense"],
                             shortname="96-pcr",
                             col_count=12,
                             dead_volume_ul=Unit(3, "microliter"),
@@ -301,7 +320,9 @@ _CONTAINER_TYPES = {
                              well_volume_ul=Unit(2000.0, "microliter"),
                              well_coating=None,
                              sterile=False,
-                             capabilities=[],
+                             capabilities=["pipette", "incubate",
+                                           "gel_separate", "gel_purify",
+                                           "cover", "stamp", "dispense"],
                              shortname="96-deep",
                              is_tube=False,
                              col_count=12,
@@ -313,7 +334,11 @@ _CONTAINER_TYPES = {
                              well_volume_ul=Unit(200.0, "microliter"),
                              well_coating=None,
                              sterile=False,
-                             capabilities=[],
+                             capabilities=["pipette", "incubate",
+                                           "gel_separate", "mag_dry",
+                                           "mag_incubate", "mag_collect",
+                                           "mag_release", "mag_mix",
+                                           "cover", "stamp", "dispense"],
                              shortname="96-v-kf",
                              is_tube=False,
                              col_count=12,
@@ -326,7 +351,11 @@ _CONTAINER_TYPES = {
                                 well_volume_ul=Unit(1000.0, "microliter"),
                                 well_coating=None,
                                 sterile=False,
-                                capabilities=[],
+                                capabilities=["pipette", "incubate",
+                                              "gel_separate", "mag_dry",
+                                              "mag_incubate", "mag_collect",
+                                              "mag_release", "mag_mix",
+                                              "cover", "stamp", "dispense"],
                                 shortname="96-deep-kf",
                                 is_tube=False,
                                 col_count=12,
@@ -338,7 +367,9 @@ _CONTAINER_TYPES = {
                              well_volume_ul=Unit(10000.0, "microliter"),
                              well_coating=None,
                              sterile=False,
-                             capabilities=[],
+                             capabilities=["pipette", "incubate",
+                                           "gel_separate", "gel_purify",
+                                           "cover", "stamp", "dispense"],
                              shortname="24-deep",
                              is_tube=False,
                              col_count=6,
@@ -350,7 +381,8 @@ _CONTAINER_TYPES = {
                                well_volume_ul=Unit(2000.0, "microliter"),
                                well_coating=None,
                                sterile=False,
-                               capabilities=[],
+                               capabilities=["pipette", "gel_separate",
+                                             "gel_purify", "incubate"],
                                shortname="micro-2.0",
                                is_tube=True,
                                col_count=1,
@@ -362,7 +394,8 @@ _CONTAINER_TYPES = {
                                well_volume_ul=Unit(1500.0, "microliter"),
                                well_coating=None,
                                sterile=False,
-                               capabilities=[],
+                               capabilities=["pipette", "gel_separate",
+                                             "gel_purify", "incubate"],
                                shortname="micro-1.5",
                                is_tube=True,
                                col_count=1,
@@ -374,7 +407,7 @@ _CONTAINER_TYPES = {
                             well_volume_ul=Unit(5000.0, "microliter"),
                             well_coating=None,
                             sterile=False,
-                            capabilities=[],
+                            capabilities=["cover", "incubate"],
                             shortname="6-flat",
                             is_tube=False,
                             col_count=3,
@@ -386,7 +419,7 @@ _CONTAINER_TYPES = {
                             well_volume_ul=Unit(80000.0, "microliter"),
                             well_coating=None,
                             sterile=False,
-                            capabilities=[],
+                            capabilities=["cover", "incubate"],
                             shortname="1-flat",
                             is_tube=False,
                             col_count=1,
