@@ -2,8 +2,8 @@ from __future__ import print_function
 import json
 import io
 from .protocol import Protocol
-from .unit import Unit
-from .container import WellGroup
+from .unit import Unit, UnitError
+from .container import WellGroup, SEAL_TYPES, COVER_TYPES
 from . import UserError
 import argparse
 import sys
@@ -95,15 +95,15 @@ def convert_param(protocol, val, typeDesc):
             return WellGroup([convert_param(protocol, a, 'aliquot') for a in val])
         except:
             label = typeDesc.get('label') or "[unknown]"
-            raise RuntimeError("The value supplied to input '%s' (type aliquot+) is improperly"
-                               " formatted." % label)
+            raise RuntimeError("The value supplied to input '%s' (type aliquot+) is improperly "
+                               "formatted." % label)
     elif type == 'aliquot++':
         try:
             return [convert_param(protocol, aqs, 'aliquot+') for aqs in val]
         except:
             label = typeDesc.get('label') or "[unknown]"
-            raise RuntimeError("The value supplied to input '%s' (type aliquot++) is improperly"
-                               " formatted." % label)
+            raise RuntimeError("The value supplied to input '%s' (type aliquot++) is improperly "
+                               "formatted." % label)
     elif type == 'container':
 
         try:
@@ -117,21 +117,26 @@ def convert_param(protocol, val, typeDesc):
             return [convert_param(protocol, cont, 'container') for cont in val]
         except:
             label = typeDesc.get('label') or "[unknown]"
-            raise RuntimeError("The value supplied to input '%s' (type container+) is improperly"
-                               " formatted." % label)
-    elif type in ['volume', 'time', 'temperature', 'length']:
-        # TODO: this should be a separate 'condition' type, rather than
-        # overloading 'temperature'.
+            raise RuntimeError("The value supplied to input '%s' (type container+) is improperly "
+                               "formatted." % label)
+    elif type in ['volume', 'time', 'length']:
         try:
-            if type == 'temperature' and \
-                    val in ['ambient', 'warm_30', 'warm_37', 'cold_4', 'cold_20', 'cold_80']:
+            return Unit.fromstring(val)
+        except UnitError as e:
+            raise RuntimeError("The value supplied (%s) as a unit of '%s' is "
+                               "improperly formatted. Units of %s must be in "
+                               "the form: 'number:unit'" % (e.value, type, type))
+    elif type == 'temperature':
+        try:
+            if val in ['ambient', 'warm_30', 'warm_37', 'cold_4', 'cold_20', 'cold_80']:
                 return val
             else:
                 return Unit.fromstring(val)
-        except (ValueError, AttributeError):
-            raise RuntimeError("Values supplied to temperature input types must"
-                               " be either storage conditions (ex: \"cold_20\")"
-                               " or temperature units in the form of \"value:unit\"")
+        except UnitError as e:
+            raise RuntimeError("Invalid temperature value for %s: temperature "
+                               "input types must be either storage conditions "
+                               "(ex: 'cold_20') or temperature units in the "
+                               "form of 'number:unit'" % e.value)
     elif type in 'bool':
         return bool(val)
     elif type in 'csv':
@@ -143,15 +148,15 @@ def convert_param(protocol, val, typeDesc):
             return int(val)
         except ValueError:
             label = typeDesc.get('label') or "[unknown]"
-            raise RuntimeError("The value supplied to input '%s' (type integer) is improperly"
-                               " formatted." % label)
+            raise RuntimeError("The value supplied to input '%s' (type integer) is improperly "
+                               "formatted." % label)
     elif type == 'decimal':
         try:
             return float(val)
         except ValueError:
             label = typeDesc.get('label') or "[unknown]"
-            raise RuntimeError("The value supplied to input '%s' (type decimal) is improperly"
-                               " formatted." % label)
+            raise RuntimeError("The value supplied to input '%s' (type decimal) is improperly "
+                               "formatted." % label)
     elif type == 'group':
         try:
             return {
@@ -164,8 +169,8 @@ def convert_param(protocol, val, typeDesc):
                                "a(n) %s field." % (label, e))
         except AttributeError:
             label = typeDesc.get('label') or "[unknown]"
-            raise RuntimeError("The value supplied to input '%s' (type group) is improperly"
-                               " formatted." % label)
+            raise RuntimeError("The value supplied to input '%s' (type group) is improperly "
+                               "formatted." % label)
     elif type == 'group+':
         try:
             return [{
@@ -173,8 +178,8 @@ def convert_param(protocol, val, typeDesc):
                     for k in typeDesc['inputs']
                     } for x in val]
         except (TypeError, AttributeError):
-            raise RuntimeError("The value supplied to input '%s' (type group+) must be in"
-                               " the form of a list of dictionaries" % typeDesc['label'])
+            raise RuntimeError("The value supplied to input '%s' (type group+) must be in "
+                               "the form of a list of dictionaries" % typeDesc['label'])
         except KeyError as e:
             label = typeDesc.get('label') or "[unknown]"
             raise RuntimeError("The value supplied to input '%s' (type group+) is missing "
@@ -201,28 +206,37 @@ def convert_param(protocol, val, typeDesc):
             return [
                 {
                     'cycles': g['cycles'],
-                    'steps': [
-                        {
-                            'duration': Unit.fromstring(s['duration']),
-                            'temperature': Unit.fromstring(s['temperature']),
-                            'read': s["read"] == "True"
-                        }
-                        if 'read' in s else
-                        {
-                            'duration': Unit.fromstring(s['duration']),
-                            'temperature': Unit.fromstring(s['temperature'])
-                        }
-                        for s in g['steps']
-                    ]
+                    'steps': [convert_param(protocol, s, 'thermocycle_step') for s in g['steps']]
                 }
                 for g in val
             ]
         except (TypeError, KeyError):
-            raise RuntimeError("Thermocycle input types must take a list of"
-                               " dictionaries in the form of:\n"
-                               "[{\"cycles\": integer, \n  \"steps\":[{\n    "
-                               "\"duration\": duration, \n    \"temperature\": "
-                               "temperature\n  }]\n}]")
+            raise RuntimeError(_thermocycle_error_text())
+
+    elif type == 'thermocycle_step':
+        try:
+            output = {'duration': Unit.fromstring(val['duration'])}
+        except UnitError as e:
+            raise RuntimeError("Invalid duration value for %s: duration input types must "
+                               "be time units in the form of 'number:unit'" % e.value)
+
+        try:
+            if 'gradient' in val:
+                output['gradient'] = {
+                    'top': Unit.fromstring(val['gradient']['top']),
+                    'bottom': Unit.fromstring(val['gradient']['bottom'])
+                }
+            else:
+                output['temperature'] = Unit.fromstring(val['temperature'])
+        except UnitError as e:
+            raise RuntimeError("Invalid temperature value for %s: thermocycle temperature "
+                               "input types must be temperature units in the form of "
+                               "'number:unit'" % e.value)
+
+        if 'read' in val:
+            output['read'] = val['read']
+
+        return output
 
     elif type == 'csv-table':
         try:
@@ -244,9 +258,9 @@ def convert_param(protocol, val, typeDesc):
         except (AttributeError, IndexError, TypeError):
             label = typeDesc.get('label') or "[unknown]"
             raise RuntimeError(
-                "The values supplied to %s (type csv-table) are improperly"
-                "formatted. Format must be a list of dictionaries with the first."
-                " dictionary comprising keys with associated column input types." % label
+                "The values supplied to %s (type csv-table) are improperly "
+                "formatted. Format must be a list of dictionaries with the first "
+                "dictionary comprising keys with associated column input types." % label
             )
 
     else:
@@ -269,7 +283,8 @@ class ProtocolInfo(object):
                 ref.get('id'),
                 ref['type'],
                 storage=ref.get('store'),
-                discard=ref.get('discard'))
+                discard=ref.get('discard'),
+                cover=ref.get('cover'))
             aqs = ref.get('aliquots')
             if aqs:
                 for idx in aqs:
@@ -337,7 +352,7 @@ class Manifest(object):
                                "associated manifest.json file." % name)
 
 
-def run(fn, protocol_name=None):
+def run(fn, protocol_name=None, seal_after_run=True):
     """
     Run the protocol specified by the function.
 
@@ -350,7 +365,11 @@ def run(fn, protocol_name=None):
     ----------
     fn : function
         Function that generates Autoprotocol
-
+    protocol_name :  str, optional
+        str matching the "name" value in the manifest.json file
+    seal_after_run : bool, optional
+        Implicitly add a seal/cover to all stored refs within the protocol
+        using seal_on_store()
     """
     parser = argparse.ArgumentParser()
     parser.add_argument(
@@ -369,6 +388,8 @@ def run(fn, protocol_name=None):
 
     try:
         fn(protocol, params)
+        if seal_after_run:
+            seal_on_store(protocol)
     except UserError as e:
         print(json.dumps({
             'errors': [
@@ -381,3 +402,128 @@ def run(fn, protocol_name=None):
         return
 
     print(json.dumps(protocol.as_dict(), indent=2))
+
+
+def _thermocycle_error_text():
+    """
+    Returns formatted error text for thermocycle value errors
+    """
+
+    return """Thermocycle input types must take a list of dictionaries in the form of:
+  [{"cycles": integer,
+    "steps": [{
+      "duration": duration,
+      "temperature": temperature
+      "read": boolean (optional)
+    }]
+  }]
+--or--
+  [{"cycles": integer,
+    "steps": [{
+      "duration": duration,
+      "gradient": {
+        "top": temperature,
+        "bottom": temperature
+      }
+      "read": boolean (optional)
+    }]
+  }]
+(You can intermix gradient and non-gradient steps)"""
+
+
+def seal_on_store(protocol):
+    '''
+    Implicitly adds seal/cover instructions to the end of a run for containers
+    that do not have a cover.   If no cover or seal instructions involving a
+    given container were present in a protocol, cover type applied defaults first to
+    "seal" if its within the capabilities of the container type, otherwise
+    to "cover".
+
+    Example Usage:
+
+        .. code-block:: python
+
+            def example_method(protocol, params):
+            cont = params['container']
+            p.transfer(cont.well("A1"), cont.well("A2"), "10:microliter")
+            p.seal(cont)
+            p.unseal(cont)
+            p.cover(cont)
+            p.uncover(cont)
+
+    Autoprotocol output
+
+        .. code-block:: json
+            {
+              "refs": {
+                "plate": {
+                  "new": "96-pcr",
+                  "cover": "standard",
+                  "store": {
+                    "where": "ambient"
+                  }
+                }
+              },
+              "instructions": [
+                {
+                  "groups": [
+                    {
+                      "transfer": [
+                        {
+                          "volume": "10.0:microliter",
+                          "to": "plate/1",
+                          "from": "plate/0"
+                        }
+                      ]
+                    }
+                  ],
+                  "op": "pipette"
+                },
+                {
+                  "object": "plate",
+                  "type": "ultra-clear",
+                  "op": "seal"
+                },
+                {
+                  "object": "plate",
+                  "op": "unseal"
+                },
+                {
+                  "lid": "standard",
+                  "object": "plate",
+                  "op": "cover"
+                },
+                {
+                  "object": "plate",
+                  "op": "uncover"
+                },
+                {
+                  "lid": "standard",
+                  "object": "plate",
+                  "op": "cover"
+                }
+              ]
+            }
+
+    '''
+    for name, ref in protocol.refs.items():
+        cover = None
+        action = None
+        if not ref.opts.get("cover") and "store" in ref.opts.keys():
+            for i in protocol.instructions:
+                if i.data.get("object") == ref.container:
+                    if i.op == "seal":
+                        cover = i.data['type']
+                        action = "seal"
+                    elif i.op == "cover":
+                        cover = i.data['lid']
+                        action = "cover"
+            if cover:
+                cov = getattr(protocol, action)
+                cov(ref.container)
+            elif "seal" in ref.container.container_type.capabilities:
+                protocol.seal(ref.container)
+            elif "cover" in ref.container.container_type.capabilities:
+                protocol.cover(ref.container)
+            else:
+                continue
